@@ -2,11 +2,19 @@ require 'spec_helper'
 
 describe 'murano::dashboard' do
 
-  let :facts do {
-    :osfamily       => 'Debian',
-  } end
+  let :facts do
+    OSDefaults.get_facts({ :osfamily => 'Debian' })
+  end
 
   shared_examples_for 'with default class parameters' do
+    let(:collect_static_command) {
+      if facts[:os_package_type] == 'ubuntu'
+        "/usr/share/openstack-dashboard/manage.py collectstatic --noinput"
+      else
+        "/usr/share/openstack-dashboard/manage.py collectstatic --noinput --clear"
+      end
+    }
+
     it { is_expected.to contain_package('murano-dashboard').with({
       :ensure => 'present',
       :name   => 'python-murano-dashboard',
@@ -26,10 +34,11 @@ describe 'murano::dashboard' do
 
     it { is_expected.to_not contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_API_URL = /)}
     it { is_expected.to_not contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_REPO_URL = /)}
+    it { is_expected.to_not contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_DASHBOARD_NAME = /)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/MAX_FILE_SIZE_MB = '5'/)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/METADATA_CACHE_DIR = '\/var\/cache\/murano-dashboard'/)}
-    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranodashboard'\] = \{'handlers': \['syslog'\], 'level': 'DEBUG'\}/)}
-    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranoclient'\] = \{'handlers': \['syslog'\], 'level': 'ERROR'\}/)}
+    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranodashboard'\] = \{'handlers': 'file', 'level': 'DEBUG'\}/)}
+    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranoclient'\] = \{'handlers': 'file', 'level': 'ERROR'\}/)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_USE_GLARE = False/)}
 
     it { is_expected.to contain_exec('clean_horizon_config').with({
@@ -38,7 +47,7 @@ describe 'murano::dashboard' do
     })}
 
     it { is_expected.to contain_exec('django_collectstatic').with({
-      :command => '/usr/share/openstack-dashboard/manage.py collectstatic --noinput --clear'
+      :command => collect_static_command
     })}
 
     it { is_expected.to contain_exec('django_compressstatic').with({
@@ -52,16 +61,25 @@ describe 'murano::dashboard' do
 
   shared_examples_for 'with parameters override' do
     let :params do {
-      :api_url               => 'http://127.0.0.1:8083',
+      :dashboard_name        => 'Application Catalog',
       :repo_url              => 'http://storage.apps.openstack.com',
       :enable_glare          => true,
       :collect_static_script => '/bin/openstack-dashboard/manage.py',
       :metadata_dir          => '/tmp/muranodashboard-cache',
       :max_file_size         => '5',
       :sync_db               => false,
+      :log_handler           => 'console',
     }
     end
 
+    let(:collect_static_command) {
+      if facts[:os_package_type] == 'ubuntu'
+        "/bin/openstack-dashboard/manage.py collectstatic --noinput"
+      else
+        "/bin/openstack-dashboard/manage.py collectstatic --noinput --clear"
+      end
+    }
+
     it { is_expected.to contain_package('murano-dashboard').with({
       :ensure => 'present',
       :name   => 'python-murano-dashboard',
@@ -79,12 +97,12 @@ describe 'murano::dashboard' do
       :order  => 2,
     })}
 
-    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_API_URL = 'http:\/\/127.0.0.1:8083'/)}
+    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_DASHBOARD_NAME = 'Application Catalog'/)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_REPO_URL = 'http:\/\/storage.apps.openstack.com'/)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/MAX_FILE_SIZE_MB = '5'/)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/METADATA_CACHE_DIR = '\/tmp\/muranodashboard-cache'/)}
-    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranodashboard'\] = \{'handlers': \['syslog'\], 'level': 'DEBUG'\}/)}
-    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranoclient'\] = \{'handlers': \['syslog'\], 'level': 'ERROR'\}/)}
+    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranodashboard'\] = \{'handlers': 'console', 'level': 'DEBUG'\}/)}
+    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranoclient'\] = \{'handlers': 'console', 'level': 'ERROR'\}/)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_USE_GLARE = True/)}
 
     it { is_expected.to contain_exec('clean_horizon_config').with({
@@ -93,7 +111,7 @@ describe 'murano::dashboard' do
     })}
 
     it { is_expected.to contain_exec('django_collectstatic').with({
-      :command => '/bin/openstack-dashboard/manage.py collectstatic --noinput --clear'
+      :command => collect_static_command
     })}
 
     it { is_expected.to contain_exec('django_compressstatic').with({
@@ -107,11 +125,11 @@ describe 'murano::dashboard' do
 
   context 'on Debian platforms' do
     let :facts do
-      {
-        :osfamily => 'Debian',
+      OSDefaults.get_facts({
+        :osfamily        => 'Debian',
         :operatingsystem => 'Debian',
-        :concat_basedir => '/var/lib/puppet/concat'
-      }
+        :concat_basedir  => '/var/lib/puppet/concat',
+      })
     end
 
     it_configures 'with default class parameters'
