@@ -2,21 +2,13 @@ require 'spec_helper'
 
 describe 'murano::db::postgresql' do
 
-  let :req_params do
-    { :password => 'pw' }
-  end
+  shared_examples_for 'murano::db::postgresql' do
+    let :req_params do
+      { :password => 'pw' }
+    end
 
-  let :pre_condition do
-    'include postgresql::server'
-  end
-
-  context 'on a RedHat osfamily' do
-    let :facts do
-      {
-          :osfamily                 => 'RedHat',
-          :operatingsystemrelease   => '7.0',
-          :concat_basedir => '/var/lib/puppet/concat'
-      }
+    let :pre_condition do
+      'include postgresql::server'
     end
 
     context 'with only required parameters' do
@@ -32,27 +24,19 @@ describe 'murano::db::postgresql' do
 
   end
 
-  context 'on a Debian osfamily' do
-    let :facts do
-      {
-          :operatingsystemrelease => '7.8',
-          :operatingsystem        => 'Debian',
-          :osfamily               => 'Debian',
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge(OSDefaults.get_facts({
+          :processorcount => 8,
           :concat_basedir => '/var/lib/puppet/concat'
-      }
-    end
-
-    context 'with only required parameters' do
-      let :params do
-        req_params
+        }))
       end
 
-      it { is_expected.to contain_postgresql__server__db('murano').with(
-        :user     => 'murano',
-        :password => 'md5c73cd23dae0b015e51ff2b38714d0bab'
-      )}
+      it_configures 'murano::db::postgresql'
     end
-
   end
 
 end
