@@ -9,7 +9,6 @@ describe 'murano::logging' do
 
   let :log_params do
     {
-        :verbose                       => 'true',
         :debug                         => 'true',
         :use_syslog                    => 'true',
         :use_stderr                    => 'false',
@@ -25,7 +24,6 @@ describe 'murano::logging' do
             'amqp'       => 'WARN',
             'amqplib'    => 'WARN',
             'boto'       => 'WARN',
-            'qpid'       => 'WARN',
             'sqlalchemy' => 'WARN',
             'suds'       => 'INFO',
             'iso8601'    => 'WARN',
@@ -64,7 +62,6 @@ describe 'murano::logging' do
       it { is_expected.to contain_murano_config('DEFAULT/use_stderr').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_murano_config('DEFAULT/use_syslog').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_murano_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_murano_config('DEFAULT/verbose').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_murano_config('DEFAULT/log_dir').with_value('/var/log/murano') }
     end
 
@@ -81,7 +78,6 @@ describe 'murano::logging' do
   shared_examples_for 'basic logging options passed' do
     context 'with passed params' do
       it { is_expected.to contain_murano_config('DEFAULT/debug').with_value(true) }
-      it { is_expected.to contain_murano_config('DEFAULT/verbose').with_value(true) }
       it { is_expected.to contain_murano_config('DEFAULT/use_syslog').with_value(true) }
       it { is_expected.to contain_murano_config('DEFAULT/use_stderr').with_value(false) }
       it { is_expected.to contain_murano_config('DEFAULT/syslog_log_facility').with_value('LOG_LOCAL0') }
@@ -106,7 +102,7 @@ describe 'murano::logging' do
       is_expected.to contain_murano_config('DEFAULT/log_config_append').with_value('/etc/murano/logging.conf')
       is_expected.to contain_murano_config('DEFAULT/publish_errors').with_value(true)
       is_expected.to contain_murano_config('DEFAULT/default_log_levels').with_value(
-                         'amqp=WARN,amqplib=WARN,boto=WARN,iso8601=WARN,qpid=WARN,requests.packages.urllib3.connectionpool=WARN,sqlalchemy=WARN,suds=INFO')
+                         'amqp=WARN,amqplib=WARN,boto=WARN,iso8601=WARN,requests.packages.urllib3.connectionpool=WARN,sqlalchemy=WARN,suds=INFO')
 
       is_expected.to contain_murano_config('DEFAULT/fatal_deprecations').with_value(true)
       is_expected.to contain_murano_config('DEFAULT/instance_format').with_value('[instance: %(uuid)s] ')
